@@ -2,11 +2,12 @@ import asyncio
 import logging
 import warnings
 from contextlib import suppress
+from typing import List
 
 from PyQt5.QtCore import Qt
-from PyQt5.QtGui import QImage, QPixmap
-from PyQt5.QtWidgets import QFrame, QVBoxLayout, QLabel, QApplication
-from requests.exceptions import RequestException
+from PyQt5.QtGui import QImage, QPixmap, QPalette
+from PyQt5.QtWidgets import QFrame, QVBoxLayout, QLabel, QApplication, QWidget
+from requests.exceptions import RequestException  # type: ignore[import]
 
 from feeluown.utils import aio
 from feeluown.utils.reader import wrap
@@ -16,7 +17,7 @@ from feeluown.library import ModelState, NotSupported, ModelFlags, ModelType
 
 from feeluown.gui.helpers import BgTransparentMixin, \
     disconnect_slots_if_has, fetch_cover_wrapper
-from feeluown.gui.widgets.menu import SongMenuInitializer
+from feeluown.gui.components import SongMenuInitializer
 from feeluown.gui.widgets.imglist import ImgListView
 from feeluown.gui.widgets.album import AlbumListModel, AlbumListView, \
     AlbumFilterProxyModel
@@ -82,11 +83,11 @@ class Renderer:
         pixmap = QPixmap(img)
         if not pixmap.isNull():
             if as_background:
-                self.meta_widget.set_cover_pixmap(None)
+                self.meta_widget.set_cover_image(None)
                 self._app.ui.right_panel.show_background_image(pixmap)
             else:
                 self._app.ui.right_panel.show_background_image(None)
-                self.meta_widget.set_cover_pixmap(pixmap)
+                self.meta_widget.set_cover_image(img)
             self._app.ui.table_container.updateGeometry()
 
     def show_albums(self, reader):
@@ -239,6 +240,8 @@ class DescLabel(QLabel):
         self.setWordWrap(True)
         self.setTextInteractionFlags(Qt.TextSelectableByMouse)
 
+        self.palette().setColor(QPalette.Background, self.palette().color(QPalette.Base))
+
 
 class TableContainer(QFrame, BgTransparentMixin):
     def __init__(self, app, parent=None):
@@ -247,14 +250,14 @@ class TableContainer(QFrame, BgTransparentMixin):
         self._app = app
         self._renderer = None
         self._table = None  # current visible table
-        self._tables = []
+        self._tables: List[QWidget] = []
 
         self._extra = None
         self.toolbar = SongsTableToolbar()
         self.tabbar = TableTabBarV2()
         self.meta_widget = TableMetaWidget(parent=self)
         self.songs_table = SongsTableView(app=self._app, parent=self)
-        self.albums_table = AlbumListView(parent=self)
+        self.albums_table = AlbumListView(parent=self, img_min_width=120)
         self.artists_table = ArtistListView(parent=self)
         self.videos_table = VideoListView(parent=self)
         self.playlists_table = PlaylistListView(parent=self)
@@ -304,7 +307,6 @@ class TableContainer(QFrame, BgTransparentMixin):
 
         self._v_layout.addWidget(self.meta_widget)
         self._v_layout.addWidget(self.toolbar)
-        self._v_layout.addSpacing(10)
         self._v_layout.addWidget(self.desc_widget)
 
         # Since QTableView has a margin on the left and right(see SongsTableDelegate),
@@ -413,8 +415,11 @@ class TableContainer(QFrame, BgTransparentMixin):
         task_name = 'play-all'
         task_spec = self._app.task_mgr.get_or_create(task_name)
         model = self.songs_table.model()
+        assert isinstance(model, SongFilterProxyModel)
+        source_model = model.sourceModel()
+        assert isinstance(source_model, SongsTableModel)
         # FIXME: think about a more elegant way to get reader.
-        reader = model.sourceModel().reader
+        reader = source_model.reader
         if reader is not None and reader.count is not None:
             self.toolbar.enter_state_playall_start()
             with suppress(ProviderIOError, asyncio.CancelledError):
@@ -452,10 +457,6 @@ class TableContainer(QFrame, BgTransparentMixin):
         warnings.warn('use readerer.show_artists please')
         aio.create_task(self.set_renderer(ArtistsCollectionRenderer(artists_g)))
 
-    def search(self, text):
-        if self.isVisible() and self.songs_table is not None:
-            self.songs_table.filter_row(text)
-
     def _add_songs_to_playlist(self, songs):
         for song in songs:
             self._app.playlist.add(song)
@@ -494,9 +495,9 @@ class TableContainer(QFrame, BgTransparentMixin):
             try:
                 song = await aio.run_in_executor(
                     None, self._app.library.song_upgrade, song)
-            except NotSupported:
+            except NotSupported as e:
                 assert ModelFlags.v2 & song.meta.flags
-                self._app.show_msg('资源提供放不支持该功能')
+                self._app.show_msg(f'资源提供方不支持该功能: {str(e)}')
                 logger.info(f'provider:{song.source} does not support song_get')
                 song.state = ModelState.cant_upgrade
             except (ProviderIOError, RequestException) as e:
